@@ -18,7 +18,8 @@ cat("Statistical Model:", "\n")
 cat(paste("     Dataset:", x$dataset),"\n")
 cat(paste("     Number of subjects:", x$ns),"\n")
 cat(paste("     Number of observations:", length(x$pred[,1])),"\n")
-cat(paste("     Number of latents classes:", x$ng), "\n")
+if(length(x$na.action))cat(paste("     Number of observations deleted:",length(x$na.action)),"\n")
+cat(paste("     Number of latent classes:", x$ng), "\n")
 cat(paste("     Number of parameters:", length(x$best))," \n")
 cat(" \n")
 cat("Iteration process:", "\n")
